@@ -140,7 +140,7 @@ volatile gboolean glib_on_error_halt = TRUE;
  * This function may cause different actions on non-UNIX platforms.
  *
  * On Windows consider using the `G_DEBUGGER` environment
- * variable (see [Running GLib Applications](glib-running.html)) and
+ * variable (see [Running GLib Applications](running.html)) and
  * calling g_on_error_stack_trace() instead.
  */
 void
@@ -243,7 +243,7 @@ g_on_error_query (const gchar *prg_name)
  * g_on_error_query(). If called directly, it will raise an
  * exception, which will crash the program. If the `G_DEBUGGER` environment
  * variable is set, a debugger will be invoked to attach and
- * handle that exception (see [Running GLib Applications](glib-running.html)).
+ * handle that exception (see [Running GLib Applications](running.html)).
  */
 void
 g_on_error_stack_trace (const gchar *prg_name)
@@ -290,7 +290,13 @@ g_on_error_stack_trace (const gchar *prg_name)
   while (1)
     {
       pid_t retval = waitpid (pid, &status, 0);
-      if (WIFEXITED (retval) || WIFSIGNALED (retval))
+      if (retval == -1)
+        {
+          if (errno == EAGAIN || errno == EINTR)
+            continue;
+          break;
+        }
+      else if (WIFEXITED (status) || WIFSIGNALED (status))
         break;
     }
 #else
@@ -491,7 +497,7 @@ stack_trace (const char * const *args)
                     }
                   break;
                 case 1:
-                  if (idx < BUFSIZE)
+                  if (idx < BUFSIZE - 1)
                     buffer[idx++] = c;
                   if ((c == '\n') || (c == '\r'))
                     {
