@@ -2,6 +2,8 @@
  * Copyright (C) 2011 Red Hat, Inc
  * Author: Matthias Clasen
  *
+ * SPDX-License-Identifier: LicenseRef-old-glib-tests
+ *
  * This work is provided "as is"; redistribution and modification
  * in whole or in part, in any medium, physical or electronic is
  * permitted without restriction.
@@ -38,8 +40,8 @@ compare_func (gconstpointer d1, gconstpointer d2, gpointer data)
   return i1 - i2;
 }
 
-static
-void test_async_queue_sort (void)
+static void
+test_async_queue_sort (void)
 {
   GAsyncQueue *q;
 
@@ -131,12 +133,11 @@ test_async_queue_destroy (void)
   g_assert_cmpint (destroy_count, ==, 4);
 }
 
-static GAsyncQueue *q;
+static GAsyncQueue *global_queue;
 
 static GThread *threads[10];
-static gint counts[10];
-static gint sums[10];
-static gint total;
+static gint counts[10];  /* (atomic) */
+static gint sums[10];  /* (atomic) */
 
 static gpointer
 thread_func (gpointer data)
@@ -146,13 +147,13 @@ thread_func (gpointer data)
 
   while (1)
     {
-      value = GPOINTER_TO_INT (g_async_queue_pop (q));
+      value = GPOINTER_TO_INT (g_async_queue_pop (global_queue));
 
       if (value == -1)
         break;
 
-      counts[pos]++;
-      sums[pos] += value;
+      g_atomic_int_inc (&counts[pos]);
+      g_atomic_int_add (&sums[pos], value);
 
       g_usleep (1000);
     }
@@ -166,48 +167,52 @@ test_async_queue_threads (void)
   gint i, j;
   gint s, c;
   gint value;
+  int total = 0;
 
-  q = g_async_queue_new ();
+  global_queue = g_async_queue_new ();
 
   for (i = 0; i < 10; i++)
     threads[i] = g_thread_new ("test", thread_func, GINT_TO_POINTER (i));
 
   for (i = 0; i < 100; i++)
     {
-      g_async_queue_lock (q);
+      g_async_queue_lock (global_queue);
       for (j = 0; j < 10; j++)
         {
           value = g_random_int_range (1, 100);
           total += value;
-          g_async_queue_push_unlocked (q, GINT_TO_POINTER (value));
+          g_async_queue_push_unlocked (global_queue, GINT_TO_POINTER (value));
         }
-      g_async_queue_unlock (q);
+      g_async_queue_unlock (global_queue);
 
       g_usleep (1000);
     }
 
   for (i = 0; i < 10; i++)
-    g_async_queue_push (q, GINT_TO_POINTER(-1));
+    g_async_queue_push (global_queue, GINT_TO_POINTER (-1));
 
   for (i = 0; i < 10; i++)
     g_thread_join (threads[i]);
 
-  g_assert_cmpint (g_async_queue_length (q), ==, 0);
+  g_assert_cmpint (g_async_queue_length (global_queue), ==, 0);
 
   s = c = 0;
 
   for (i = 0; i < 10; i++)
     {
-      g_assert_cmpint (sums[i], >, 0);
-      g_assert_cmpint (counts[i], >, 0);
-      s += sums[i];
-      c += counts[i];
+      int sums_i = g_atomic_int_get (&sums[i]);
+      int counts_i = g_atomic_int_get (&counts[i]);
+
+      g_assert_cmpint (sums_i, >, 0);
+      g_assert_cmpint (counts_i, >, 0);
+      s += sums_i;
+      c += counts_i;
     }
 
   g_assert_cmpint (s, ==, total);
   g_assert_cmpint (c, ==, 1000);
 
-  g_async_queue_unref (q);
+  g_async_queue_unref (global_queue);
 }
 
 static void
@@ -218,6 +223,15 @@ test_async_queue_timed (void)
   gint64 start, end, diff;
   gpointer val;
 
+  GDateTime *dt = g_date_time_new_now_utc ();
+  int year = g_date_time_get_year (dt);
+  g_date_time_unref (dt);
+  if (year >= 2038)
+    {
+      g_test_skip ("Test relies on GTimeVal which is Y2038 unsafe and will cause a failure.");
+      return;
+    }
+
   g_get_current_time (&tv);
   if (g_test_undefined ())
     {
